Interactable

Struct Interactable 

pub struct Interactable {
    pub element: Box<dyn UiElement>,
    pub event: InteractableEvent,
    pub signal: SignalTrigger,
}
Available on crate feature el_interactable only.
Wrapper that allows adding click and hover events to any element

Fields

element: Box<dyn UiElement>

The wrapped element that will be interactable

event: InteractableEvent

Event to listen for

signal: SignalTrigger

Signal that will be called if the element was clicked in the current frame

Implementations

Source

impl Interactable

pub fn new<S: Signal, F: Fn() -> S + 'static>( element: Box<dyn UiElement>, event: InteractableEvent, signal: F, ) -> Self