RectFrame

Struct RectFrame 

pub struct RectFrame {
    pub color: FillColor,
    pub image: Option<ImageHandle>,
    pub top_left: FramePoint2d,
    pub bottom_right: FramePoint2d,
    pub corner_radius: Corners<f32>,
}
A rectangular frame

Can optionally be tinted, textured, and have rounded corners

Fields

color: FillColor

Background color of the frame\

If the container has a background texture, it will be multiplied by this color

image: Option<ImageHandle>

Background texture of the frame

Can be used in conjunction with the background color
In this case, the texture will be shaded by the color

Please note that if the background color is NOT set (or set to transparent), the texture will NOT be visible
This is because the texture is multiplied by the color, and if the color is transparent, the texture will be too\

top_left: FramePoint2d

Top left corner of the rectangle

bottom_right: FramePoint2d

Bottom right corner of the rectangle

corner_radius: Corners<f32>

Corner radius of the frame

Implementations

Source

impl RectFrame

pub fn color(color: impl Into<FillColor>) -> Self

Create a new RectFrame with the given color

pub fn image(image: ImageHandle) -> Self

Create a new RectFrame with the given image\

Color will be set to WHITE to ensure the image is visible

pub fn color_image(color: impl Into<FillColor>, image: ImageHandle) -> Self

Create a new RectFrame with the given color and image

pub fn with_corner_radius(self, radius: impl Into<Corners<f32>>) -> Self

Set the corner radius of the RectFrame

pub fn with_inset(self, inset: f32) -> Self

Inset the rectangle by the given amount in pixels