pub struct MouseState {
pub current_position: Vec2,
pub prev_position: Vec2,
pub buttons: HashMap<MouseButton, MouseButtonMeta, BuildNoHashHasher<u16>>,
pub released_buttons: HashMap<MouseButton, MouseButtonMeta, BuildNoHashHasher<u16>>,
}Fields
current_position: Vec2Current position of the mouse pointer
prev_position: Vec2Position of the mouse pointer on the previous frame
Current state of each mouse button (if down)
mouse buttons that were released in the current frame