Response

Struct Response 

pub struct Response {
    pub size: Vec2,
    pub hints: Hints,
    pub user_data: Option<Box<dyn Any>>,
    pub should_wrap: bool,
}

Fields

size: Vec2

Computed size of the element

hints: Hints

Hints for the layout system, can be used to optimize the layout engine.
These will never cause the UI to be rendered differently (assuming the values are correct)

user_data: Option<Box<dyn Any>>

Arbitrary user data, can be used to pass data (for example, cache) between measure and process stages

should_wrap: bool

If true, the element should always cause the content to wrap to the next line
(the element itself gets wrapped to the next line too)

You should almost never set this, and the exact behavior may change in the future

Currently, this forces wrapping even if Container::wrap is set to false

Implementations

Source

impl Response

pub fn rect(&self, position: Vec2) -> Rect