pub struct Image {
pub image: ImageHandle,
pub size: Size2d,
pub color: FillColor,
pub corner_radius: Corners<f32>,
}Available on crate feature
el_image only.Fields
image: ImageHandleImage handle to draw
size: Size2dSize of the image.
- If one of the dimensions is
Size::Auto, the image will be scaled to fit the other dimension
(aspect ratio is preserved) - If both dimensions are
Size::Auto, the image will be drawn at its original size - All other values behave as expected
color: FillColorColor of the image
Image will get multiplied/tinted by this color or gradient
corner_radius: Corners<f32>Corner radius of the image
Implementations
Sourceimpl Image
impl Image
Sourcepub fn with_color(self, value: impl Into<FillColor>) -> Self
pub fn with_color(self, value: impl Into<FillColor>) -> Self
Sets the color field of this struct.
Sourcepub fn with_corner_radius(self, value: impl Into<Corners<f32>>) -> Self
pub fn with_corner_radius(self, value: impl Into<Corners<f32>>) -> Self
Sets the corner_radius field of this struct.