pub struct Interactable {
pub element: Box<dyn UiElement>,
pub event: InteractableEvent,
pub signal: SignalTrigger,
}Available on crate feature
el_interactable only.Expand description
Wrapper that allows adding click and hover events to any element
Fields
element: Box<dyn UiElement>The wrapped element that will be interactable
event: InteractableEventEvent to listen for
signal: SignalTriggerSignal that will be called if the element was clicked in the current frame
Implementations
Sourceimpl Interactable
impl Interactable